@@ -1,11 +1,10 @@
-import sys
 from datetime import date, datetime, timezone
 from enum import Enum
 from typing import Mapping
 
-from loguru import logger
 from pydantic import BaseModel
 
+from ._logger import logger
 from .dev._dependency import infer_dependencies
 from .dev._initialize import initialize_metadata
 from .dev._jupyter_communicate import notebook_path
@@ -101,11 +100,10 @@ class DisplayMeta:
 
 
 class Header:
-    """Metadata header class.
+    """Metadata header.
 
-    An object of this class displays nbproject metadata fields
-    for the current notebook on initialization. If the notebook doesn't have
-    nbproject metadata, it will be initialized and written to the notebook.
+    - Displays nbproject metadata fields for the current notebook.
+    - If the notebook doesn't have nbproject metadata, initializes & writes it to disk.
     """
 
     def __init__(self, filepath=None, env=None):
@@ -115,40 +113,31 @@ class Header:
             filepath_env = notebook_path(return_env=True)
             if filepath_env is None:
                 raise RuntimeError(
-                    "can't infer the name of the current notebook, "
-                    "you are probably not inside a jupyter notebook"
+                    "Can't infer the name of the current notebook, "
+                    "you are probably not inside a jupyter notebook."
                 )
             filepath = filepath_env[0]
 
-        # without this, we have ugly timestamps
-        logger.configure(
-            handlers=[
-                dict(
-                    sink=sys.stdout,
-                    format="{message}",
-                ),
-            ],
-        )
-
         if env is None:
             env = filepath_env[1]
         # This is a quirk we run into when passing filepath manually!
         # We just assume jupyter lab as an environment for now
         if env is None:
             env = "lab"
-            logger.info("... assuming editor is Jupyter Lab")
+            logger.info("Assuming editor is Jupyter Lab.")
 
         try:
             nb = read_notebook(filepath)
         except FileNotFoundError:
             raise RuntimeError(
-                "try passing the filepath manually to nbproject.Header()"
+                "Try passing the filepath manually to nbproject.Header()."
             )
         # initialize
         if "nbproject" not in nb.metadata:
             logger.info(
-                "To initialize nbproject for this notebook:\n* In Jupyter Lab: hit"
-                " restart when asked!"
+                "To initialize nbproject for this notebook:\n"  # noqa
+                "- In Jupyter Lab: confirm restart when asked.\n"
+                "- In Jupyter Notebook & VS Code: reload the notebook from disk."
             )
 
             if env == "lab":
@@ -182,7 +171,9 @@ class Header:
             table.append(["id", dm.id()])
             table.append(["time_init", dm.time_init()])
             table.append(["time_run", dm.time_run(time_run)])
-            table.append(["version", dm.version()])
+
+            version = dm.version()
+            table.append(["version", version])
 
             dep_store = dm.dependency()
             add_pkgs = None
@@ -190,22 +181,15 @@ class Header:
             if dep_store is not None:
                 # only display stored dependencies for published notebooks
                 # for draft notebooks, they have little meaning
-                if (
-                    "version" in nb.metadata["nbproject"]
-                    and nb.metadata["nbproject"]["version"] != "draft"  # noqa
-                ):
+                if version != "draft":
                     table.append(["dependency_store", " ".join(dep_store)])
                 add_pkgs = [pkg.partition("==")[0] for pkg in dep_store]
 
             dep_live = dm.dependency(
                 infer_dependencies(nb, add_pkgs, pin_versions=True)
             )
-            suffix = ""
-            if (
-                "version" in nb.metadata["nbproject"]
-                and nb.metadata["nbproject"]["version"] != "draft"  # noqa
-            ):
-                suffix = "_live"
+
+            suffix = "" if version == "draft" else "_live"
             table.append([f"dependency{suffix}", " ".join(dep_live)])
 
             display_html(table_html(table))
