@@ -5,9 +5,7 @@ from loguru import logger
 from ._notebook import Notebook
 
 
-def check_integrity(
-    nb: Notebook, ignore_code: Optional[str] = None
-) -> list[tuple[Optional[int], Optional[int]]]:
+def check_integrity(nb: Notebook, ignore_code: Optional[str] = None) -> list:
     """Get integrity status of the passed notebook.
 
     Returns those cell transitions that violate execution at increments of 1
@@ -42,8 +40,8 @@ def check_integrity(
         violations.pop()
 
     if len(violations) > 0:
-        logger.warning(f"... cells {violations} were not run consecutively")
+        logger.warning(f"Cells {violations} were not run consecutively.")
     else:
-        logger.info("... notebook cells increment at 1: Awesome!")
+        logger.info("Cell numbers increase at increments of 1: Awesome!")
 
     return violations  # type: ignore
